@@ -29,12 +29,18 @@ class BaseTransferRequestTest(base.BaseDnsV2Test):
 class TransferRequestTest(BaseTransferRequestTest):
     credentials = ['primary', 'alt']
 
+    @classmethod
+    def setup_credentials(cls):
+        # Do not create network resources for these test.
+        cls.set_network_resources()
+        super(TransferRequestTest, cls).setup_credentials()
+
     @classmethod
     def setup_clients(cls):
         super(TransferRequestTest, cls).setup_clients()
 
-        cls.zone_client = cls.os.zones_client
-        cls.client = cls.os.transfer_request_client
+        cls.zone_client = cls.os_primary.zones_client
+        cls.client = cls.os_primary.transfer_request_client
         cls.alt_client = cls.os_alt.transfer_request_client
 
     @decorators.idempotent_id('2381d489-ad84-403d-b0a2-8b77e4e966bf')
@@ -191,10 +197,16 @@ class TransferRequestTest(BaseTransferRequestTest):
 
 class TestTransferRequestNotFound(BaseTransferRequestTest):
 
+    @classmethod
+    def setup_credentials(cls):
+        # Do not create network resources for these test.
+        cls.set_network_resources()
+        super(TestTransferRequestNotFound, cls).setup_credentials()
+
     @classmethod
     def setup_clients(cls):
         super(TestTransferRequestNotFound, cls).setup_clients()
-        cls.client = cls.os.transfer_request_client
+        cls.client = cls.os_primary.transfer_request_client
 
     @decorators.idempotent_id('d255f72f-ba24-43df-9dba-011ed7f4625d')
     def test_show_transfer_request_404(self):
@@ -227,10 +239,16 @@ class TestTransferRequestNotFound(BaseTransferRequestTest):
 
 class TestTransferRequestInvalidId(BaseTransferRequestTest):
 
+    @classmethod
+    def setup_credentials(cls):
+        # Do not create network resources for these test.
+        cls.set_network_resources()
+        super(TestTransferRequestInvalidId, cls).setup_credentials()
+
     @classmethod
     def setup_clients(cls):
         super(TestTransferRequestInvalidId, cls).setup_clients()
-        cls.client = cls.os.transfer_request_client
+        cls.client = cls.os_primary.transfer_request_client
 
     @decorators.idempotent_id('2205dd19-ecc7-4c68-9e89-63c47d642b07')
     def test_show_transfer_request_invalid_uuid(self):
