@@ -27,6 +27,12 @@ class BaseZonesImportTest(base.BaseDnsV2Test):
 
 
 class ZonesImportTest(BaseZonesImportTest):
+    @classmethod
+    def setup_credentials(cls):
+        # Do not create network resources for these test.
+        cls.set_network_resources()
+        super(ZonesImportTest, cls).setup_credentials()
+
     @classmethod
     def setup_clients(cls):
         super(ZonesImportTest, cls).setup_clients()
